# Copyright 2016 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

import os
import os.path
from StringIO import StringIO


def decrypt_content(content):
    """Decrypt 'content' using the SampleDataKeys.regular_key.

    :raises TypeError: if 'content' is not an instance of str.
    :raises RuntimeError: If gpgme is not installed. This function should only
        be called within a test suite, where additional dependencies such as
        gpgme can be installed.
    """
    if isinstance(content, unicode):
        raise TypeError('Content cannot be Unicode.')
    try:
        import gpgme
    except ImportError:
        raise RuntimeError(
            "Could not import gpgme. This function should only be called "
            "from within a test suite run where gpgme has been installed.")

    # import the secret key:
    newkey = open(
        os.path.join(
            os.path.dirname(__file__),
            '..',
            'tests',
            'gpgkeys',
            'data',
            'test@canonical.com.sec'))
    password = 'test'

    # Make sure that gpg-agent doesn't interfere.
    if 'GPG_AGENT_INFO' in os.environ:
        del os.environ['GPG_AGENT_INFO']

    context = gpgme.Context()
    context.armor = True
    context.import_(newkey)

    # setup containers
    cipher = StringIO(content)
    plain = StringIO()

    def passphrase_cb(uid_hint, passphrase_info, prev_was_bad, fd):
        os.write(fd, '%s\n' % password)

    context.passphrase_cb = passphrase_cb

    # Do the decryption.
    try:
        context.decrypt(cipher, plain)
    except gpgme.GpgmeError:
        return None

    return plain.getvalue()
