# Copyright 2016 Canonical Ltd.  This software is licensed under the GNU
# Affero General Public License version 3 (see the file LICENSE).

from textwrap import dedent


class SampleDataKeys(object):

    """Storage to the various sampledata keys the test key service holds."""

    regular_key = "A419 AE86 1E88 BC9E 04B9 C26F BA2B 9389 DFD2 0543"

    sign_only_key = "447D BF38 C4F9 C4ED 7522  46B7 7D88 9137 17B0 5A8F"

    revoked_key = "84D2 05F0 3E1E 6709 6CB5  4E26 2BE8 3793 AACC D97C"

    expired_key = "ECA5 B797 586F 2E27 381A  16CF DE6C 9167 046C 6D63"


class SampleDataDocuments(object):

    """SampleData documents that can be used in tests. Unless otherwise
    specified, all documents have been signed with the sign_only key above.
    """

    clearsigned_document = dedent('''\
        -----BEGIN PGP SIGNED MESSAGE-----
        Hash: SHA1

        This is a test document.
        -----BEGIN PGP SIGNATURE-----
        Version: GnuPG v1

        iEYEARECAAYFAlauvhMACgkQfYiRNxewWo9RXgCeNTm2LHPTklDfkhPNDXlZZO8w
        +PgAn0jxaoVxm3cftv8VfHzs+2HfXU0H
        =3rvY
        -----END PGP SIGNATURE-----
        ''')

    clearsigned_document_multiple_signatures = dedent('''\
        -----BEGIN PGP SIGNED MESSAGE-----
        Hash: SHA1

        This is a test document.
        -----BEGIN PGP SIGNATURE-----
        Version: GnuPG v1

        iEYEARECAAYFAlauvhMACgkQfYiRNxewWo9RXgCeNTm2LHPTklDfkhPNDXlZZO8w
        +PgAn0jxaoVxm3cftv8VfHzs+2HfXU0H
        =3rvY
        -----END PGP SIGNATURE-----
        -----BEGIN PGP SIGNATURE-----
        Version: GnuPG v1

        iEYEARECAAYFAlauvhMACgkQfYiRNxewWo9RXgCeNTm2LHPTklDfkhPNDXlZZO8w
        +PgAn0jxaoVxm3cftv8VfHzs+2HfXU0H
        =3rvY
        -----END PGP SIGNATURE-----
        ''')

    clearsigned_document_no_signature = dedent('''\
        -----BEGIN PGP SIGNED MESSAGE-----
        Hash: SHA1

        This is a test document.
        -----BEGIN PGP SIGNATURE-----
        -----END PGP SIGNATURE-----
        ''')

    clearsigned_with_unknown_key = dedent('''\
        -----BEGIN PGP SIGNED MESSAGE-----
        Hash: SHA1

        This is a test document.
        -----BEGIN PGP SIGNATURE-----
        Version: GnuPG v1

        iQEcBAEBAgAGBQJWsUJVAAoJELsvu710zTSIC54IAJrsV3wOZQ62YQRdjSo4Q1Cl
        173W4HZOdfMKCgORI7K4N2SIMHM4EzBiGUHknZTQm9HV8qv0E0FOCDHkzQuVwKV4
        /elcCupBIecOZXKp/KLSJuctcxM5z5Xj49Hh9hYB2phhejkXJ31PHaW3nxeApSRf
        lh1ix9lhbnGzc+FkWVUfy0Sfcl9v5luE6R7c48CSV+APg7aImcVXiJWO6pwViLXm
        z84Sdj3cx5cMFkbC+KWogiHh8aOuuCEgWl+cEPysM/fMBu+PlJGF5c6pQ4sJUTqS
        WbZP8HyM2p2pQarf7EaMhAmsltLuirTdfmlmI4CUtQ5HSYqqs96hXVDL+70JQIs=
        =JXjx
        -----END PGP SIGNATURE-----''')

    clearsigned_with_unsigned_parts = dedent('''\
        This part has not been signed.
        -----BEGIN PGP SIGNED MESSAGE-----
        Hash: SHA1

        This is a test document.
        -----BEGIN PGP SIGNATURE-----
        Version: GnuPG v1

        iEYEARECAAYFAlauvhMACgkQfYiRNxewWo9RXgCeNTm2LHPTklDfkhPNDXlZZO8w
        +PgAn0jxaoVxm3cftv8VfHzs+2HfXU0H
        =3rvY
        -----END PGP SIGNATURE-----
        Neither has this part!
        ''')
