# Copyright 2009-2016 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from urllib import urlopen

from testtools import TestCase
from testtools.matchers import (
    DirExists,
    Not,
    )

from gpgservice_client.testing.keyserver import TestKeyServerFixture
from gpgservice_client.testing.keyserver.web import GREETING

__metaclass__ = type


class TestTestKeyServerFixture(TestCase):

    def test_url(self):
        # The url is the one that gpghandler is configured to hit.
        host = self.getUniqueString()
        port = self.getUniqueInteger()
        fixture = TestKeyServerFixture(host, port)
        self.assertEqual(
            'http://%s:%d' % (host, port),
            fixture.url)

    def test_starts_properly(self):
        # Make sure the tac starts properly and that we can load the page.
        fixture = TestKeyServerFixture()
        fixture.setUp()
        self.addCleanup(fixture.tearDown)
        content = urlopen(fixture.url).readline()
        self.assertEqual(GREETING, content)

    def test_cleans_up_working_dir(self):
        with TestKeyServerFixture() as fixture:
            working_dir = fixture.root
        self.assertThat(working_dir, Not(DirExists()))


def test_suite():
    from unittest import TestLoader
    return TestLoader().loadTestsFromName(__name__)
